
Changelog
=========

0.2.1 (2025-10-19)
------------------

* Move ``msgspec`` to optional dependencies (it has some big issues on 3.14). It's not really optional but perhaps a fork may work better on 3.14.

0.2.0 (2025-10-13)
------------------

* Replace ``siruta.extras.LOCALITIES_BY_NAME`` with ``siruta.extras.LOCALITIES_BY_COUNTY_ID_BY_NAME`` (to avoid name collisions).

0.1.1 (2025-10-10)
------------------

* First release on PyPI.
